@@ -3,9 +3,11 @@ DIALS Regression Data Manager
 https://github.com/dials/data
 """
 
-__all__ = []
+from __future__ import annotations
+
+__all__: list = []
 __author__ = """Markus Gerstel"""
 __email__ = "dials-support@lists.sourceforge.net"
-__version__ = "2.1.45"
-__commit__ = "88daa53b7e54b7962b920894bf8d0def2d61cf85"
+__version__ = "2.4.19"
+__commit__ = "ebccaa8f208adfcc02ab89a916c7d56487148ce1"
 __version_tuple__ = tuple(int(x) for x in __version__.split("."))
